@@ -148,7 +148,11 @@ function do_action(){
 
     docs)
       shift
-      do_action coverage
+      if [ "$1" == "--no-coverage" ]; then
+        shift
+      else
+        do_action coverage
+      fi
       run "Clean autogenerated doc stubs" rm -rf "${FOLDER}/docs/_autosummary"
       run "Clean previously built docs" rm -rf "${FOLDER}/docs/build"
       run "Build Documentation" python3 setup.py build_sphinx "$@"
@@ -156,7 +160,11 @@ function do_action(){
 
     quality)
       shift
-      do_action coverage
+      if [ "$1" == "--no-coverage" ]; then
+        shift
+      else
+        do_action coverage
+      fi
       rm ./op.log
       touch ./op.log
       run --append "Compute Cyclomatic Complexity (CC)" radon cc -s -i '__pending*' ./src
@@ -179,14 +187,14 @@ function do_action(){
       run "Ensure working directory is clean." require_working_directory_clean
       do_action unit-test
       do_action coverage
-      do_action quality
+      do_action quality --no-coverage
       do_action style
-      do_action docs
+      do_action docs --no-coverage
     ;;
 
     release-major)
       do_action prerelease
-      run "Increment the version number (major)." bumpversion minor
+      run "Increment the version number (major)." bumpversion major
       run "Push changes" git push
       run "Push tags"    git push --tags
     ;;
@@ -200,7 +208,7 @@ function do_action(){
 
     release-patch)
       do_action prerelease
-      run "Increment the version number (patch)." bumpversion minor
+      run "Increment the version number (patch)." bumpversion patch
       run "Push changes" git push
       run "Push tags"    git push --tags
     ;;
